@@ -38,6 +38,8 @@ public:
     GVContactsTable (QObject *parent = 0);
     ~GVContactsTable ();
 
+    void setTempStore(const QString &strTemp);
+
     void deinitModel ();
     void initModel ();
 
@@ -97,6 +99,9 @@ private:
 private:
     ContactsModel *modelContacts;
 
+    //! Path to the temp directory to store all contact photos
+    QString         strTempStore;
+
     //! Username and password for google authentication
     QString         strUser, strPass;
     //! The authentication string returned by the contacts API
